@@ -5,7 +5,8 @@ from __future__ import generator_stop
 import ast
 import tokenize
 
-from typing import Iterable, Tuple
+from typing import Iterable
+from typing import Tuple
 
 import attr
 import more_itertools
@@ -48,8 +49,7 @@ class Checker:
     )  # type: Iterable[tokenize.TokenInfo]
 
     def run(self) -> Iterable[_ERROR]:
-        """
-        Run checker.
+        """Run checker.
 
         :yields: Errors found.
         """
